@@ -26,10 +26,7 @@ CACHE_BACKEND = 'sqlite'
 CACHE_NAME = 'requests_cache_test'
 FAST_SAVE = False
 
-if 'HTTPBIN_URL' not in os.environ:
-    os.environ['HTTPBIN_URL'] = 'http://httpbin.org/'
-
-HTTPBIN_URL = os.environ.get('HTTPBIN_URL')
+HTTPBIN_URL = os.getenv('HTTPBIN_URL', 'http://httpbin.org/')
 
 
 def httpbin(*suffix):
@@ -44,6 +41,16 @@ class CacheTestCase(unittest.TestCase):
         self.s.cache.clear()
         requests_cache.uninstall_cache()
 
+    @classmethod
+    def tearDownClass(cls):
+        super(CacheTestCase, cls).tearDownClass()
+        filename = "{0}.{1}".format(CACHE_NAME, CACHE_BACKEND)
+        if os.path.exists(filename):
+            try:
+                os.unlink(filename)
+            except OSError:
+                pass
+
     def test_expire_cache(self):
         delay = 1
         url = httpbin('delay/%s' % delay)
@@ -283,14 +290,18 @@ class CacheTestCase(unittest.TestCase):
         n = 100
         url = httpbin("stream/%s" % n)
         r = self.s.get(url, stream=True)
+        first_char = r.raw.read(1)
         lines = list(r.iter_lines())
+        self.assertTrue(first_char)
         self.assertEquals(len(lines), n)
 
         for i in range(2):
             r = self.s.get(url, stream=True)
+            first_char_cached = r.raw.read(1)
             self.assertTrue(r.from_cache)
             cached_lines = list(r.iter_lines())
             self.assertEquals(cached_lines, lines)
+            self.assertEquals(first_char, first_char_cached)
 
     def test_headers_in_get_query(self):
         url = httpbin("get")
